Structs
- Step
Result - Training step result.
Functions
- train_
step - Train an MLP (or any differentiable graph) for one step.
forward_fnbuilds the computation graph on the tape and returns (loss_id, param_ids). The training loop runs backward, extracts gradients, and updates params.